@@ -25,7 +25,7 @@
 // Author     : Jean-Charles Lefebvre
 // Created On : 2010-03-28 23:54:12
 //
-// $Id: App.cpp 166 2010-10-16 08:49:34Z jc.lefebvre $
+// $Id: App.cpp 210 2010-10-29 20:43:06Z jc.lefebvre $
 //
 //***************************************************************************
 
@@ -47,11 +47,12 @@ QString App::ms_strOutputDir;
 //---------------------------------------------------------------------------
 App::App (int& nArgc, char** ppszArgv)
 : QApplication(nArgc, ppszArgv)
+, m_Batt(this)
 {
   // force POSIX locale for *printf() calls, this is required by the
   // Exporter classes.  we do this here because the QApplication()
   // constructor seems to apply locale settings by itself.
-  setlocale(LC_NUMERIC, "C");
+  setlocale(LC_NUMERIC, "C"); // QLocale::setDefault(QLocale::c());
 
   // init members
   m_eState            = STATE_STOPPED;
@@ -60,26 +61,27 @@ App::App (int& nArgc, char** ppszArgv)
   m_uiLastFixWrite    = 0;
 
   // load pixmaps
-  m_pPixCellModeNone    = new QPixmap(":/icons/cellmode-none-170.png");
-  m_pPixCellMode2G      = new QPixmap(":/icons/cellmode-2g-170.png");
-  m_pPixCellMode3G      = new QPixmap(":/icons/cellmode-3g-170.png");
-  m_pPixStoppedGrey     = new QPixmap(":/icons/stopped-grey-48.png");
-  m_pPixStoppedGreen    = new QPixmap(":/icons/stopped-green-48.png");
-  m_pPixStoppedOrange   = new QPixmap(":/icons/stopped-orange-48.png");
-  m_pPixStoppedRed      = new QPixmap(":/icons/stopped-red-48.png");
-  m_pPixPausedGrey      = new QPixmap(":/icons/paused-grey-48-nomargin.png");
-  m_pPixPausedGreen     = new QPixmap(":/icons/paused-green-48-nomargin.png");
-  m_pPixPausedOrange    = new QPixmap(":/icons/paused-orange-48-nomargin.png");
-  m_pPixPausedRed       = new QPixmap(":/icons/paused-red-48-nomargin.png");
-  m_pPixRecordingGrey   = new QPixmap(":/icons/recording-grey-48-nomargin.png");
-  m_pPixRecordingGreen  = new QPixmap(":/icons/recording-green-48-nomargin.png");
-  m_pPixRecordingOrange = new QPixmap(":/icons/recording-orange-48-nomargin.png");
-  m_pPixRecordingRed    = new QPixmap(":/icons/recording-red-48-nomargin.png");
-  m_pPixStart           = new QPixmap(":/icons/start-48.png");
-  m_pPixStop            = new QPixmap(":/icons/stop-48.png");
-  m_pPixPause           = new QPixmap(":/icons/pause-48.png");
-  m_pPixSnap            = new QPixmap(":/icons/snap-48.png");
-  m_pPixState           = m_pPixStoppedGrey;
+  m_pPixCellModeNone     = new QPixmap(":/icons/cellmode-none-170.png");
+  m_pPixCellMode2G       = new QPixmap(":/icons/cellmode-2g-170.png");
+  m_pPixCellMode3G       = new QPixmap(":/icons/cellmode-3g-170.png");
+  m_pPixStoppedGrey      = new QPixmap(":/icons/stopped-grey-48.png");
+  m_pPixStoppedGreen     = new QPixmap(":/icons/stopped-green-48.png");
+  m_pPixStoppedOrange    = new QPixmap(":/icons/stopped-orange-48.png");
+  m_pPixStoppedRed       = new QPixmap(":/icons/stopped-red-48.png");
+  m_pPixPausedGrey       = new QPixmap(":/icons/paused-grey-48-nomargin.png");
+  m_pPixPausedGreen      = new QPixmap(":/icons/paused-green-48-nomargin.png");
+  m_pPixPausedOrange     = new QPixmap(":/icons/paused-orange-48-nomargin.png");
+  m_pPixPausedRed        = new QPixmap(":/icons/paused-red-48-nomargin.png");
+  m_pPixRecordingGrey    = new QPixmap(":/icons/recording-grey-48-nomargin.png");
+  m_pPixRecordingGreen   = new QPixmap(":/icons/recording-green-48-nomargin.png");
+  m_pPixRecordingOrange  = new QPixmap(":/icons/recording-orange-48-nomargin.png");
+  m_pPixRecordingRed     = new QPixmap(":/icons/recording-red-48-nomargin.png");
+  m_pPixStart            = new QPixmap(":/icons/start-48.png");
+  m_pPixStop             = new QPixmap(":/icons/stop-48.png");
+  m_pPixPause            = new QPixmap(":/icons/pause-48.png");
+  m_pPixSnap             = new QPixmap(":/icons/snap-48.png");
+  m_pPixMeansOfTransport = new QPixmap(":/icons/mot-48.png");
+  m_pPixState            = m_pPixStoppedGrey;
 
   // connect to AppSettings signals
   this->connect(
@@ -162,6 +164,7 @@ App::~App (void)
   delete m_pPixStop;
   delete m_pPixPause;
   delete m_pPixSnap;
+  delete m_pPixMeansOfTransport;
 }
 
 
@@ -279,38 +282,59 @@ bool App::setState (App::State eNewState)
   {
     if (eNewState == STATE_STARTED)
     {
-      QByteArray strPath;
-      QString    strTrackName;
+      WndStart wndStart(m_pWndMain);
 
-      if (m_Settings.getAskTrackName())
+      if (!wndStart.doExec())
       {
-        strTrackName = this->askTrackName();
-        if (strTrackName == ".")
-        {
-          QMaemo5InformationBox::information(
-            m_pWndMain,
-            tr("Action canceled !"));
-          return false;
-        }
+        QMaemo5InformationBox::information(
+          m_pWndMain,
+          tr("Action canceled !"));
+        return false;
       }
 
       m_uiFixesWritten = 0;
       m_uiLastFixWrite = 0;
 
-      strPath  = App::outputDir().toAscii();
-      strPath += "/gpstrack-";
-      strPath += Util::timeStringForFileName();
-      if (!strTrackName.isEmpty())
+      // open/create file
+      if (wndStart.startMode() == WndStart::STARTMODE_APPENDTRACK)
       {
-        strPath += '-';
-        strPath += strTrackName.toAscii();
+        if (!m_GPSRFile.openAppend(qPrintable(wndStart.filePath()), qPrintable(wndStart.trackName())))
+        {
+          QMessageBox::critical(
+            m_pWndMain,
+            "",
+            tr("Could not append track to file %1 !").arg(qPrintable(wndStart.filePath())));
+          return false;
+        }
       }
-      strPath += ".gpsr";
-
-      if (!m_GPSRFile.openWrite(strPath.constData(), true))
+      else
       {
-        QMessageBox::critical(m_pWndMain, "", tr("Could not create output file at %1 !").arg(strPath.constData()));
-        return false;
+        if (!m_GPSRFile.openNew(qPrintable(wndStart.filePath()), qPrintable(wndStart.trackName()), true))
+        {
+          QMessageBox::critical(
+            m_pWndMain,
+            "",
+            tr("Could not create output file %1 !").arg(qPrintable(wndStart.filePath())));
+          return false;
+        }
+      }
+
+      // write means of transport if user selected it
+      if (wndStart.meansOfTransport() != 0)
+      {
+        QString strOtherName =
+          wndStart.meansOfTransport() == GPSRFile::MEANSTRANSPORT_OTHER ?
+          wndStart.otherMeansOfTransportName() :
+          "";
+
+        m_GPSRFile.writeMeansOfTransport(
+          time(0),
+          wndStart.meansOfTransport(),
+          qPrintable(strOtherName));
+
+        m_pWndMain->setMeansOfTransport(
+          wndStart.meansOfTransport(),
+          strOtherName);
       }
 
       m_pPixState = m_pPixRecordingGrey;
@@ -444,30 +468,6 @@ const char* App::getStateStr (void) const
 
 
 
-//---------------------------------------------------------------------------
-// askTrackName
-//---------------------------------------------------------------------------
-QString App::askTrackName (void)
-{
-  QString strTrackName;
-  bool bOk = false;
-
-  strTrackName = QInputDialog::getText(
-    m_pWndMain,
-    tr("Track name ?"),
-    tr("Please enter track name or leave blank :"),
-    QLineEdit::Normal,
-    "",
-    &bOk).trimmed();
-
-  if (!bOk)
-    return QString(".");
-
-  strTrackName.replace('.', '_');
-
-  return strTrackName;
-}
-
 //---------------------------------------------------------------------------
 // closeGPSRFile
 //---------------------------------------------------------------------------
@@ -481,19 +481,21 @@ void App::closeGPSRFile (void)
     }
     else
     {
-      QByteArray strPath;
+      QByteArray strPath(m_GPSRFile.getPath());
+      bool bAppend = m_GPSRFile.isAppending();
 
-      strPath = m_GPSRFile.getPath();
       m_GPSRFile.close();
 
-      if (!m_uiFixesWritten)
+      if (m_GPSRFile.discardedAfterClose())
       {
-        QMaemo5InformationBox::information(
-          m_pWndMain,
-          tr("Deleting track file because nothing was written in it !"),
-          5000);
-        qDebug("Deleting %s because nothing was written in it.", strPath.constData());
-        QFile::remove(strPath);
+        QString strMsg;
+
+        if (bAppend)
+          strMsg = tr("Removed track data from this file because no location fix was received while recording !");
+        else
+          strMsg = tr("File was deleted because no location fix was received while recording !");
+
+        QMaemo5InformationBox::information(m_pWndMain, strMsg, 5000);
       }
     }
   }
