@@ -25,7 +25,7 @@
 // Author     : Jean-Charles Lefebvre
 // Created On : 2010-04-27 13:06:48
 //
-// $Id: AppSettings.cpp 166 2010-10-16 08:49:34Z jc.lefebvre $
+// $Id: AppSettings.cpp 213 2010-10-31 10:17:24Z jc.lefebvre $
 //
 //***************************************************************************
 
@@ -36,24 +36,31 @@
 // Static Members
 //---------------------------------------------------------------------------
 static const char* SETTINGNAME_OUTPUTDIR = "OutputDir";
-//
-static const char* SETTINGNAME_LOGSTEP            = "LogStep";
-static const char* SETTINGNAME_GPSASSISTED        = "GpsAssisted";
-static const char* SETTINGNAME_GPSALWAYSCONNECTED = "GpsAlwaysConnected";
-static const char* SETTINGNAME_ASKTRACKNAME       = "AskTrackName";
-static const char* SETTINGNAME_ASKPOINTNAME       = "AskPointName";
-static const char* SETTINGNAME_ASKPAUSENAME       = "AskPauseName";
-static const char* SETTINGNAME_UNITSYSTEM         = "UnitSystem";
-static const char* SETTINGNAME_HORIZSPEEDUNIT     = "HorizSpeedUnit";
-static const char* SETTINGNAME_PREVENTBLANKSCREEN = "PreventBlankScreen";
-//
+
+static const char* SETTINGNAME_LOGSTEP             = "LogStep";
+static const char* SETTINGNAME_GPSASSISTED         = "GpsAssisted";
+static const char* SETTINGNAME_GPSALWAYSCONNECTED  = "GpsAlwaysConnected";
+static const char* SETTINGNAME_ALWAYSCREATENEWFILE = "AlwaysCreateNewFile";
+static const char* SETTINGNAME_ASKTRACKNAME        = "AskTrackName"; // obsolete
+static const char* SETTINGNAME_ASKPOINTNAME        = "AskPointName";
+static const char* SETTINGNAME_ASKPAUSENAME        = "AskPauseName";
+static const char* SETTINGNAME_UNITSYSTEM          = "UnitSystem";
+static const char* SETTINGNAME_HORIZSPEEDUNIT      = "HorizSpeedUnit";
+static const char* SETTINGNAME_PREVENTBLANKSCREEN  = "PreventBlankScreen";
+
+static const char* SETTINGNAME_LASTMEANSOFTRANSPORT      = "LastMeansOfTransport";
+static const char* SETTINGNAME_LASTOTHERMEANSOFTRANSPORT = "LastOtherMeansOfTransport";
+
+static const char* SETTINGNAME_CONVERT_TXT          = "ConvertTxt";
 static const char* SETTINGNAME_CONVERT_CSV          = "ConvertCsv";
 static const char* SETTINGNAME_CONVERT_GPX          = "ConvertGpx";
 static const char* SETTINGNAME_CONVERT_KML          = "ConvertKml";
 static const char* SETTINGNAME_CONVERT_EXPORTPAUSES = "ConvertExportPauses";
-//
+
+static const char* SETTINGNAME_TXT_INCLUDELOCFIX = "TxtIncludeLocationFix";
+
 static const char* SETTINGNAME_CSV_SEPARATOR = "CsvSeparator";
-//
+
 static const char* SETTINGNAME_KML_ZIPPED       = "KmlZipped";
 static const char* SETTINGNAME_KML_LINECOLOR    = "KmlLineColor";
 static const char* SETTINGNAME_KML_LINEWIDTH    = "KmlLineWidth";
@@ -105,6 +112,9 @@ AppSettings::AppSettings (QObject* pParent/*=0*/)
 
   // refresh cloned log step value
   this->getLogStep_Impl();
+
+  // delete obsolete settings to cleanup resulting file/registry
+  m_Settings.remove(SETTINGNAME_ASKTRACKNAME);
 }
 
 //---------------------------------------------------------------------------
@@ -237,20 +247,20 @@ bool AppSettings::getGpsAlwaysConnected (void)
 }
 
 //---------------------------------------------------------------------------
-// AskTrackName
+// AlwaysCreateNewFile
 //---------------------------------------------------------------------------
-void AppSettings::setAskTrackName (bool bEnable)
+void AppSettings::setAlwaysCreateNewFile (bool bEnable)
 {
-  m_Settings.setValue(SETTINGNAME_ASKTRACKNAME, QVariant(bEnable));
+  m_Settings.setValue(SETTINGNAME_ALWAYSCREATENEWFILE, QVariant(bEnable));
 }
 
-bool AppSettings::getAskTrackName (void)
+bool AppSettings::getAlwaysCreateNewFile (void)
 {
-  QVariant var = m_Settings.value(SETTINGNAME_ASKTRACKNAME);
+  QVariant var = m_Settings.value(SETTINGNAME_ALWAYSCREATENEWFILE);
   if (var.canConvert(QVariant::Bool))
     return var.toBool();
 
-  return AppSettings::defaultAskTrackName();
+  return AppSettings::defaultAlwaysCreateNewFile();
 }
 
 //---------------------------------------------------------------------------
@@ -354,6 +364,70 @@ bool AppSettings::getPreventBlankScreen (void)
   return AppSettings::defaultPreventBlankScreen();
 }
 
+//---------------------------------------------------------------------------
+// LastMeansOfTransport
+//---------------------------------------------------------------------------
+void AppSettings::setLastMeansOfTransport (quint8 ucMeansOfTransport)
+{
+  m_Settings.setValue(SETTINGNAME_LASTMEANSOFTRANSPORT, QVariant((int)ucMeansOfTransport));
+}
+
+quint8 AppSettings::getLastMeansOfTransport (void)
+{
+  QVariant var = m_Settings.value(SETTINGNAME_LASTMEANSOFTRANSPORT);
+  if (var.canConvert(QVariant::Int))
+  {
+    bool bOk = false;
+    int  i = var.toInt(&bOk);
+
+    if (bOk && GPSRFile::isValidMeansOfTransport((quint8)i))
+      return (quint8)i;
+    else
+      this->setLastMeansOfTransport(AppSettings::defaultMeansOfTransport());
+  }
+
+  return AppSettings::defaultMeansOfTransport();
+}
+
+//---------------------------------------------------------------------------
+// LastOtherMeansOfTransport
+//---------------------------------------------------------------------------
+void AppSettings::setLastOtherMeansOfTransport (const QByteArray& strOtherMeansOfTransport)
+{
+  QString str = GPSRFile::validateOtherMeansOfTransport(strOtherMeansOfTransport.constData());
+  m_Settings.setValue(SETTINGNAME_LASTOTHERMEANSOFTRANSPORT, QVariant(QLatin1String(qPrintable(str))));
+}
+
+QByteArray AppSettings::getLastOtherMeansOfTransport (void)
+{
+  QVariant var = m_Settings.value(SETTINGNAME_LASTOTHERMEANSOFTRANSPORT);
+  if (var.type() == QVariant::String)
+  {
+    QString str = GPSRFile::validateOtherMeansOfTransport(var.toString());
+    this->setLastOtherMeansOfTransport(qPrintable(str));
+    return qPrintable(str);
+  }
+
+  return QByteArray();
+}
+
+//---------------------------------------------------------------------------
+// ConvertTxt
+//---------------------------------------------------------------------------
+void AppSettings::setConvertTxt (bool bEnable)
+{
+  m_Settings.setValue(SETTINGNAME_CONVERT_TXT, QVariant(bEnable));
+}
+
+bool AppSettings::getConvertTxt (void)
+{
+  QVariant var = m_Settings.value(SETTINGNAME_CONVERT_TXT);
+  if (var.canConvert(QVariant::Bool))
+    return var.toBool();
+
+  return AppSettings::defaultConvertTxt();
+}
+
 //---------------------------------------------------------------------------
 // ConvertCsv
 //---------------------------------------------------------------------------
@@ -422,6 +496,23 @@ bool AppSettings::getConvertExportPauses (void)
   return AppSettings::defaultConvertExportPauses();
 }
 
+//---------------------------------------------------------------------------
+// TxtIncludeLocationFix
+//---------------------------------------------------------------------------
+void AppSettings::setTxtIncludeLocationFix (bool bInclude)
+{
+  m_Settings.setValue(SETTINGNAME_TXT_INCLUDELOCFIX, QVariant(bInclude));
+}
+
+bool AppSettings::getTxtIncludeLocationFix (void)
+{
+  QVariant var = m_Settings.value(SETTINGNAME_TXT_INCLUDELOCFIX);
+  if (var.canConvert(QVariant::Bool))
+    return var.toBool();
+
+  return ExporterSinkTxt::defaultIncludelocationFix();
+}
+
 //---------------------------------------------------------------------------
 // CsvSeparator
 //---------------------------------------------------------------------------
@@ -432,7 +523,7 @@ void AppSettings::setCsvSeparator (char cSep)
 
 char AppSettings::getCsvSeparator (void)
 {
-  QVariant var = m_Settings.value(SETTINGNAME_KML_LINECOLOR);
+  QVariant var = m_Settings.value(SETTINGNAME_CSV_SEPARATOR);
   if (var.canConvert(QVariant::Char))
   {
     char c = var.toChar().toAscii();
