@@ -25,7 +25,7 @@
 // Author     : Jean-Charles Lefebvre
 // Created On : 2010-03-25 14:53:26
 //
-// $Id: WndMain.cpp 166 2010-10-16 08:49:34Z jc.lefebvre $
+// $Id: WndMain.cpp 216 2010-10-31 18:29:18Z jc.lefebvre $
 //
 //***************************************************************************
 
@@ -45,11 +45,9 @@ WndMain::WndMain (QMainWindow* pParent/*=0*/)
 
   this->menuBar()->clear();
   m_pMenuStartStop = this->menuBar()->addAction(tr("Start"), this, SLOT(onClickedStartStop()));
-  m_pMenuSnap      = this->menuBar()->addAction(tr("Snap"), this, SLOT(onClickedSnap()));
   m_pMenuConfig    = this->menuBar()->addAction(tr("Settings"), this, SLOT(onClickedConfig()));
   m_pMenuConvert   = this->menuBar()->addAction(tr("Convert"), this, SLOT(onClickedConvert()));
   m_pMenuAbout     = this->menuBar()->addAction(tr("About"), this, SLOT(onClickedAbout()));
-  m_pMenuSnap->setEnabled(false);
 
   this->createWidgets();
   this->clearFixFields();
@@ -64,6 +62,14 @@ WndMain::WndMain (QMainWindow* pParent/*=0*/)
     App::instance()->location(),
     SIGNAL(sigLocationFix(Location*, const LocationFixContainer*, bool)),
     SLOT(onLocationFix(Location*, const LocationFixContainer*, bool)) );
+
+  this->connect(
+    App::instance()->battery(),
+    SIGNAL(sigBatteryStatusChanged(int, int, int, bool)),
+    SLOT(onBatteryStatusChanged(int, int, int, bool)) );
+
+  // force refresh battery status
+  App::instance()->battery()->pollBattery();
 }
 
 //---------------------------------------------------------------------------
@@ -75,6 +81,23 @@ WndMain::~WndMain (void)
 
 
 
+//---------------------------------------------------------------------------
+// setMeansOfTransport
+//---------------------------------------------------------------------------
+void WndMain::setMeansOfTransport (quint8 ucMeansOfTransport, const QString& strOtherMeansOfTransport)
+{
+  if (m_pLblMeansOfTransport)
+  {
+    AppSettings& settings = *App::instance()->settings();
+
+    m_pLblMeansOfTransport->setText(GPSRFile::fullMeansOfTransportToLabel(
+      settings.getLastMeansOfTransport(),
+      settings.getLastOtherMeansOfTransport().constData() ));
+  }
+}
+
+
+
 //---------------------------------------------------------------------------
 // closeEvent
 //---------------------------------------------------------------------------
@@ -154,6 +177,15 @@ void WndMain::createWidgets (void)
   m_pLblLastWrittenFixTime = new QLabel();
   m_pLblLastWrittenFixTime->setDisabled(true);
 
+  m_pLblHorizEp = new QLabel();
+  m_pLblHorizEp->setDisabled(true);
+
+  m_pLblMeansOfTransport = new QLabel();
+  m_pLblMeansOfTransport->setDisabled(true);
+
+  m_pLblBattery = new QLabel();
+  m_pLblBattery->setDisabled(true);
+
   m_pBtnPauseResume = new QPushButton(QIcon(*App::instance()->pixStart()), QString());
   this->connect(m_pBtnPauseResume, SIGNAL(clicked()), SLOT(onClickedPauseResume()));
 
@@ -161,7 +193,11 @@ void WndMain::createWidgets (void)
   m_pBtnSnap->setEnabled(false);
   this->connect(m_pBtnSnap, SIGNAL(clicked()), SLOT(onClickedSnap()));
 
-  m_pBtnCell = new QPushButton(tr("Cell Tower"));
+  m_pBtnMOT = new QPushButton(QIcon(*App::instance()->pixMeansOfTransport()), QString());
+  m_pBtnMOT->setEnabled(false);
+  this->connect(m_pBtnMOT, SIGNAL(clicked()), SLOT(onClickedMeansOfTransport()));
+
+  m_pBtnCell = new QPushButton(tr("CELL"));
   m_pBtnCell->setEnabled(false);
   this->connect(m_pBtnCell, SIGNAL(clicked()), SLOT(onClickedCell()));
 }
@@ -185,6 +221,7 @@ void WndMain::showFix (void)
   QFormLayout* pForm1   = new QFormLayout();
   QFormLayout* pForm2   = new QFormLayout();
   QFormLayout* pForm3   = new QFormLayout();
+  QFormLayout* pForm4   = new QFormLayout();
   QWidget*     pBlank   = new QWidget();
   QHBoxLayout* pButtons = new QHBoxLayout();
 
@@ -207,9 +244,14 @@ void WndMain::showFix (void)
   pForm3->addRow(tr("Waypoints :"), m_pLblFixesWritten);
   pForm3->addRow(tr("Last waypoint :"), m_pLblLastWrittenFixTime);
 
+  pForm4->setSpacing(8);
+  pForm4->addRow(tr("HorizEP :"), m_pLblHorizEp);
+  pForm4->addRow(tr("Transport :"), m_pLblMeansOfTransport);
+  pForm4->addRow(tr("Battery :"), m_pLblBattery);
+
   {
-    QPushButton* pBtnSat   = new QPushButton(tr("Satellites"));
-    QPushButton* pBtnSpeed = new QPushButton(tr("Speed"));
+    QPushButton* pBtnSat   = new QPushButton(tr("SAT"));
+    QPushButton* pBtnSpeed = new QPushButton(tr("SPD"));
 
     this->connect(pBtnSat, SIGNAL(clicked()), SLOT(onClickedSat()));
     this->connect(pBtnSpeed, SIGNAL(clicked()), SLOT(onClickedSpeed()));
@@ -218,6 +260,7 @@ void WndMain::showFix (void)
     pButtons->addWidget(m_pLblStatusIcon);
     pButtons->addWidget(m_pBtnPauseResume);
     pButtons->addWidget(m_pBtnSnap);
+    pButtons->addWidget(m_pBtnMOT);
     pButtons->addWidget(pBtnSat);
     pButtons->addWidget(pBtnSpeed);
     pButtons->addWidget(m_pBtnCell);
@@ -228,6 +271,7 @@ void WndMain::showFix (void)
   pGrid->addLayout(pForm2,   0, 1);
   pGrid->addWidget(pBlank,   1, 0);
   pGrid->addLayout(pForm3,   2, 0);
+  pGrid->addLayout(pForm4,   2, 1);
   pGrid->addLayout(pButtons, 3, 0, 1, 2, Qt::AlignBottom);
 
   pWidget->setLayout(pGrid);
@@ -252,6 +296,10 @@ void WndMain::clearFixFields (void)
   m_pLblTimeFixed->clear();
   m_pLblFixesWritten->clear();
   m_pLblLastWrittenFixTime->clear();
+
+  m_pLblHorizEp->clear();
+  //m_pLblMeansOfTransport->clear();
+  //m_pLblBattery->clear();
 }
 
 
@@ -272,9 +320,9 @@ void WndMain::onClickedStartStop (void)
     m_pLblStatus->setText(tr("Stopped"));
 
     m_pMenuStartStop->setText(tr("Start"));
-    m_pMenuSnap->setEnabled(false);
     m_pBtnPauseResume->setIcon(QIcon(*pApp->pixStart()));
     m_pBtnSnap->setEnabled(false);
+    m_pBtnMOT->setEnabled(false);
     m_pMenuConvert->setEnabled(true);
   }
   else if (pApp->getState() == App::STATE_STOPPED)
@@ -287,9 +335,9 @@ void WndMain::onClickedStartStop (void)
     m_pLblStatus->setText(tr("Started"));
 
     m_pMenuStartStop->setText(tr("Stop"));
-    m_pMenuSnap->setEnabled(true);
     m_pBtnPauseResume->setIcon(QIcon(*pApp->pixPause()));
     m_pBtnSnap->setEnabled(true);
+    m_pBtnMOT->setEnabled(true);
     m_pMenuConvert->setEnabled(false);
   }
   else
@@ -314,18 +362,18 @@ void WndMain::onClickedPauseResume (void)
     if (!pApp->setState(App::STATE_PAUSED))
       return;
 
-    m_pMenuSnap->setEnabled(false);
     m_pBtnPauseResume->setIcon(QIcon(*pApp->pixStart()));
     m_pBtnSnap->setEnabled(false);
+    m_pBtnMOT->setEnabled(false);
   }
   else if (pApp->getState() == App::STATE_PAUSED)
   {
     if (!pApp->setState(App::STATE_STARTED))
       return;
 
-    m_pMenuSnap->setEnabled(true);
     m_pBtnPauseResume->setIcon(QIcon(*pApp->pixPause()));
     m_pBtnSnap->setEnabled(true);
+    m_pBtnMOT->setEnabled(true);
   }
 }
 
@@ -409,6 +457,45 @@ void WndMain::onClickedConvert (void)
     this->clearFixFields();
 }
 
+//---------------------------------------------------------------------------
+// onClickedMeansOfTransport
+//---------------------------------------------------------------------------
+void WndMain::onClickedMeansOfTransport (void)
+{
+  AppSettings& settings = *App::instance()->settings();
+  WndMeansOfTransport wndMOT(this);
+  bool bOk;
+  QString strOtherLabel;
+
+  Q_ASSERT(App::instance()->getState() == App::STATE_STARTED);
+  if (App::instance()->getState() != App::STATE_STARTED)
+    return;
+
+  bOk = wndMOT.doExec(
+    settings.getLastMeansOfTransport(),
+    settings.getLastOtherMeansOfTransport().constData());
+
+  if (!bOk)
+  {
+    QMaemo5InformationBox::information(
+      this,
+      tr("Action canceled !"));
+    return;
+  }
+
+  if (wndMOT.meansOfTransport() == GPSRFile::MEANSTRANSPORT_OTHER)
+    strOtherLabel = wndMOT.otherMeansOfTransportName();
+
+  App::instance()->outFile()->writeMeansOfTransport(
+    time(0),
+    wndMOT.meansOfTransport(),
+    qPrintable(strOtherLabel));
+
+  this->setMeansOfTransport(
+    settings.getLastMeansOfTransport(),
+    settings.getLastOtherMeansOfTransport().constData() );
+}
+
 //---------------------------------------------------------------------------
 // onClickedSat
 //---------------------------------------------------------------------------
@@ -503,6 +590,7 @@ void WndMain::onLocationFix (Location* pLocation, const LocationFixContainer* pF
   m_pLblFixAlt->setText(QString::number(fix.hasFields(FIXFIELD_ALT) ? fix.getAlt(settings.getUnitSystem()) : 0.0) + " " + QString(fix.getAltSuffix(settings.getUnitSystem())));
   m_pLblFixTrack->setText(QString::number((isnan(fix.getTrackDeg()) ? 0.0 : fix.getTrackDeg()), 'f', 1) + QChar(L'\x00b0'));
   m_pLblFixSpeed->setText(QString::number((fix.hasFields(FIXFIELD_SPEED) ? fix.getSpeed(settings.getHorizSpeedUnit()) : 0.0), 'f', 2) + " " + QString(fix.getSpeedSuffix(settings.getHorizSpeedUnit())));
+  m_pLblHorizEp->setText(QString::number((isnan(fix.getHorizEp(settings.getUnitSystem())) ? 0.0 : fix.getHorizEp(settings.getUnitSystem())), 'f', 2) + " " + QString(fix.getHorizEpSuffix(settings.getUnitSystem())));
 
   // miscellaneous
   m_pLblTimeFixed->setText(App::instance()->lastTimeSetup() == 0 ? tr("NO") : tr("YES"));
@@ -519,3 +607,26 @@ void WndMain::onLocationFix (Location* pLocation, const LocationFixContainer* pF
 
   this->setUpdatesEnabled(true);
 }
+
+//---------------------------------------------------------------------------
+// onBatteryStatusChanged
+//---------------------------------------------------------------------------
+void WndMain::onBatteryStatusChanged (int iCurrent, int iLastFull, int iDesign, bool bCharging)
+{
+  QString strStatus;
+
+  //qDebug("Battery charge : curr:%i lastfull:%i design:%i ischarg:%i",
+  //  iCurrent, iLastFull, iDesign, bCharging?1:0);
+
+  if (bCharging)
+  {
+    strStatus = tr("Charging");
+  }
+  else
+  {
+    double rPercent = double(iCurrent) * 100.0 / double(iDesign);
+    strStatus = QString::number(rPercent, 'f', 1) + "%";
+  }
+
+  m_pLblBattery->setText(strStatus);
+}
